@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import BatchResponse
 
-url_bases = ["https?://batch.(.+).amazonaws.com"]
+url_bases = [r"https?://batch\.(.+)\.amazonaws.com"]
 
 url_paths = {
     "{0}/v1/createcomputeenvironment$": BatchResponse.dispatch,
