@@ -128,6 +128,8 @@ class BaseMockAWS:
             attr_value = getattr(klass, attr)
             if not hasattr(attr_value, "__call__"):
                 continue
+            if not hasattr(attr_value, "__name__"):
+                continue
 
             # Check if this is a classmethod. If so, skip patching
             if inspect.ismethod(attr_value) and attr_value.__self__ is klass:
@@ -448,7 +450,7 @@ class BotocoreEventMockAWS(BaseMockAWS):
             responses_mock.add(
                 CallbackResponse(
                     method=method,
-                    url=re.compile(r"https?://.+.amazonaws.com/.*"),
+                    url=re.compile(r"https?://.+\.amazonaws.com/.*"),
                     callback=not_implemented_callback,
                     stream=True,
                     match_querystring=False,
@@ -457,7 +459,7 @@ class BotocoreEventMockAWS(BaseMockAWS):
             botocore_mock.add(
                 CallbackResponse(
                     method=method,
-                    url=re.compile(r"https?://.+.amazonaws.com/.*"),
+                    url=re.compile(r"https?://.+\.amazonaws.com/.*"),
                     callback=not_implemented_callback,
                     stream=True,
                     match_querystring=False,
@@ -479,9 +481,11 @@ MockAWS = BotocoreEventMockAWS
 
 class ServerModeMockAWS(BaseMockAWS):
     def reset(self):
-        import requests
+        call_reset_api = os.environ.get("MOTO_CALL_RESET_API")
+        if not call_reset_api or call_reset_api.lower() != "false":
+            import requests
 
-        requests.post("http://localhost:5000/moto-api/reset")
+            requests.post("http://localhost:5000/moto-api/reset")
 
     def enable_patching(self):
         if self.__class__.nested_count == 1:
