@@ -25,6 +25,13 @@ class DatabaseMigrationServiceBackend(BaseBackend):
         self.__dict__ = {}
         self.__init__(region_name)
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "dms"
+        )
+
     def create_replication_task(
         self,
         replication_task_identifier,
