@@ -3,7 +3,7 @@ from __future__ import unicode_literals
 from .responses import EBResponse
 
 url_bases = [
-    r"https?://elasticbeanstalk.(?P<region>[a-zA-Z0-9\-_]+).amazonaws.com",
+    r"https?://elasticbeanstalk\.(?P<region>[a-zA-Z0-9\-_]+)\.amazonaws.com",
 ]
 
 url_paths = {
