@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import ElasticTranscoderResponse
 
 url_bases = [
-    "https?://elastictranscoder.(.+).amazonaws.com",
+    r"https?://elastictranscoder\.(.+)\.amazonaws.com",
 ]
 
 
