@@ -12,3 +12,10 @@ class InvalidRequestException(JsonRESTError):
         super(InvalidRequestException, self).__init__(
             "InvalidRequestException", message, **kwargs
         )
+
+
+class ValidationException(JsonRESTError):
+    def __init__(self, message, **kwargs):
+        super(ValidationException, self).__init__(
+            "ValidationException", message, **kwargs
+        )
