@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import GlacierResponse
 
-url_bases = ["https?://glacier.(.+).amazonaws.com"]
+url_bases = [r"https?://glacier\.(.+)\.amazonaws.com"]
 
 response = GlacierResponse()
 
