@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import KinesisVideoResponse
 
 url_bases = [
-    "https?://kinesisvideo.(.+).amazonaws.com",
+    r"https?://kinesisvideo\.(.+)\.amazonaws.com",
 ]
 
 
