@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import KinesisVideoArchivedMediaResponse
 
 url_bases = [
-    r"https?://.*\.kinesisvideo.(.+).amazonaws.com",
+    r"https?://.*\.kinesisvideo\.(.+)\.amazonaws.com",
 ]
 
 
