@@ -24,7 +24,7 @@ class Key(CloudFormationModel):
         self.policy = policy or self.generate_default_policy()
         self.key_usage = key_usage
         self.key_state = "Enabled"
-        self.description = description
+        self.description = description or ""
         self.enabled = True
         self.region = region
         self.account_id = ACCOUNT_ID
@@ -159,6 +159,13 @@ class KmsBackend(BaseBackend):
         self.key_to_aliases = defaultdict(set)
         self.tagger = TaggingService(key_name="TagKey", value_name="TagValue")
 
+    @staticmethod
+    def default_vpc_endpoint_service(service_region, zones):
+        """Default VPC endpoint service."""
+        return BaseBackend.default_vpc_endpoint_service_factory(
+            service_region, zones, "kms"
+        )
+
     def create_key(
         self, policy, key_usage, customer_master_key_spec, description, tags, region
     ):
@@ -346,7 +353,8 @@ class KmsBackend(BaseBackend):
 
         return plaintext, ciphertext_blob, arn
 
-    def list_resource_tags(self, key_id):
+    def list_resource_tags(self, key_id_or_arn):
+        key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             return self.tagger.list_tags_for_resource(key_id)
         raise JsonRESTError(
@@ -354,7 +362,8 @@ class KmsBackend(BaseBackend):
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def tag_resource(self, key_id, tags):
+    def tag_resource(self, key_id_or_arn, tags):
+        key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.tag_resource(key_id, tags)
             return {}
@@ -363,7 +372,8 @@ class KmsBackend(BaseBackend):
             "The request was rejected because the specified entity or resource could not be found.",
         )
 
-    def untag_resource(self, key_id, tag_names):
+    def untag_resource(self, key_id_or_arn, tag_names):
+        key_id = self.get_key_id(key_id_or_arn)
         if key_id in self.keys:
             self.tagger.untag_resource_using_names(key_id, tag_names)
             return {}
