@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import ResourceGroupsResponse
 
-url_bases = ["https?://resource-groups(-fips)?.(.+).amazonaws.com"]
+url_bases = [r"https?://resource-groups(-fips)?\.(.+)\.amazonaws.com"]
 
 url_paths = {
     "{0}/delete-group$": ResourceGroupsResponse.dispatch,
