@@ -3,8 +3,8 @@ from __future__ import unicode_literals
 from .responses import S3ResponseInstance
 
 url_bases = [
-    "https?://s3(.*).amazonaws.com",
-    r"https?://(?P<bucket_name>[a-zA-Z0-9\-_.]*)\.?s3(.*).amazonaws.com",
+    r"https?://s3(.*)\.amazonaws.com",
+    r"https?://(?P<bucket_name>[a-zA-Z0-9\-_.]*)\.?s3(.*)\.amazonaws.com",
 ]
 
 url_paths = {
