@@ -2,7 +2,7 @@ from __future__ import unicode_literals
 from .responses import SageMakerResponse
 
 url_bases = [
-    "https?://api.sagemaker.(.+).amazonaws.com",
+    r"https?://api.sagemaker\.(.+)\.amazonaws.com",
 ]
 
 url_paths = {
