@@ -1,7 +1,7 @@
 from __future__ import unicode_literals
 from .responses import SQSResponse
 
-url_bases = ["https?://(.*?)(queue|sqs)(.*?).amazonaws.com"]
+url_bases = [r"https?://(.*\.)?(queue|sqs)\.(.*\.)?amazonaws\.com"]
 
 dispatch = SQSResponse().dispatch
 
