@@ -1,9 +1,7 @@
 from __future__ import unicode_literals
 from .responses import SupportResponse
 
-url_bases = [
-    "https?://support.(.+).amazonaws.com",
-]
+url_bases = [r"https?://support\.(.+)\.amazonaws\.com"]
 
 
 url_paths = {
